//#define XERR
#include "round.ih"

std::ostream &Round::insert(std::ostream &out) const
{
    out << "age: " << static_cast<size_t>(round(d_age));

    for (auto const &modality: d_modalities)    
        out << ", " << modality;

    return out;
}

